@@ -3,7 +3,7 @@ import typing
 from collections.abc import Iterable, Mapping, MutableMapping, MutableSequence, Sequence
 from copy import deepcopy
 from dataclasses import fields, is_dataclass
-from types import EllipsisType, GenericAlias
+from types import GenericAlias
 from typing import (
     Any,
     ClassVar,
@@ -18,76 +18,30 @@ from typing import (
 from weakref import WeakValueDictionary
 
 from haiway.attributes.annotations import (
-    AttributeAnnotation,
     ObjectAttribute,
     resolve_self_attribute,
 )
+from haiway.attributes.attribute import Attribute
 from haiway.attributes.coding import AttributesJSONEncoder
 from haiway.attributes.path import AttributePath
 from haiway.attributes.specification import type_specification
 from haiway.attributes.validation import ValidationContext, ValidationError
 from haiway.types import (
     MISSING,
+    Default,
     DefaultValue,
-    Immutable,
     Missing,
     TypeSpecification,
     not_missing,
 )
 
-__all__ = (
-    "Attribute",
-    "State",
-)
-
-
-class Attribute[Value](Immutable):
-    name: str
-    alias: str | None
-    annotation: AttributeAnnotation
-    required: bool
-    default: DefaultValue[Value]
-    specification: TypeSpecification | None
-
-    def validate(
-        self,
-        value: Any,
-        /,
-    ) -> Value:
-        if value is MISSING:
-            return self.annotation.validate(self.default())
-
-        else:
-            return self.annotation.validate(value)
-
-    def validate_from(
-        self,
-        mapping: Mapping[str, Any],
-        /,
-    ) -> Value:
-        value: Any
-        if self.alias is None:
-            value = mapping.get(
-                self.name,
-                self.default(),
-            )
-
-        else:
-            value = mapping.get(
-                self.alias,
-                mapping.get(
-                    self.name,
-                    self.default(),
-                ),
-            )
-
-        return self.annotation.validate(value)
+__all__ = ("State",)
 
 
 @dataclass_transform(
     kw_only_default=True,
     frozen_default=True,
-    field_specifiers=(),
+    field_specifiers=(Default,),
 )
 class StateMeta(type):
     """
@@ -95,7 +49,7 @@ class StateMeta(type):
 
     This metaclass is responsible for:
     - Processing attribute annotations and defaults
-    - Building ``StateField`` entries from resolved ``AttributeAnnotation`` metadata
+    - Building ``Attribute`` entries from resolved ``AttributeAnnotation`` metadata
     - Setting up validation for attributes
     - Managing generic type parameters and specialization
     - Creating immutable class instances
@@ -105,11 +59,11 @@ class StateMeta(type):
     and validation logic.
     """
 
-    __IMMUTABLE__: EllipsisType = ...
     __SELF_ATTRIBUTE__: ObjectAttribute
     __TYPE_PARAMETERS__: Mapping[str, Any] | None
     __SPECIFICATION__: TypeSpecification | None
     __FIELDS__: Sequence[Attribute]
+    __slots__: tuple[str, ...]
 
     def __new__(
         mcs,
@@ -171,10 +125,10 @@ class StateMeta(type):
                     if field.required:
                         required_fields.append(field.name)
 
-        cls.__SELF_ATTRIBUTE__ = self_attribute
-        cls.__TYPE_PARAMETERS__ = type_parameters
-        cls.__SPECIFICATION__ = (
-            {  # pyright: ignore[reportAttributeAccessIssue]
+        cls.__SELF_ATTRIBUTE__ = self_attribute  # pyright: ignore[reportConstantRedefinition]
+        cls.__TYPE_PARAMETERS__ = type_parameters  # pyright: ignore[reportConstantRedefinition]
+        cls.__SPECIFICATION__ = (  # pyright: ignore[reportAttributeAccessIssue, reportConstantRedefinition]
+            {
                 "type": "object",
                 "properties": specification_fields,
                 "required": required_fields,
@@ -183,7 +137,7 @@ class StateMeta(type):
             if specification_fields is not None
             else None
         )
-        cls.__FIELDS__ = tuple(fields)
+        cls.__FIELDS__ = tuple(fields)  # pyright: ignore[reportConstantRedefinition]
         cls.__slots__ = tuple(field.name for field in fields)  # pyright: ignore[reportAttributeAccessIssue]
         cls.__match_args__ = cls.__slots__  # pyright: ignore[reportAttributeAccessIssue]
         cls._ = AttributePath(cls, attribute=cls)  # pyright: ignore[reportCallIssue, reportUnknownMemberType, reportAttributeAccessIssue]
@@ -199,7 +153,7 @@ class StateMeta(type):
         self,
         instance: Any,
     ) -> bool:
-        instance_type: type[Any] = type(instance)
+        instance_type: type[Any] = type(instance)  # pyright: ignore[reportUnknownVariableType]
         if not self.__subclasscheck__(instance_type):
             return False
 
@@ -276,16 +230,16 @@ class StateMeta(type):
         return True
 
 
-def _resolve_default[Value](
-    value: DefaultValue[Value] | Value | Missing,
-) -> DefaultValue[Value]:
+def _resolve_default(
+    value: DefaultValue | Any | Missing,
+) -> DefaultValue:
     if isinstance(value, DefaultValue):
-        return cast(DefaultValue[Value], value)
+        return value
 
-    return DefaultValue[Value](
-        value,
+    return DefaultValue(
+        default=value,
+        default_factory=MISSING,
         env=MISSING,
-        factory=MISSING,
     )
 
 
@@ -772,7 +726,7 @@ class State(metaclass=StateMeta):
         str
             ``repr`` string mirroring ``__str__`` for readability.
         """
-        attributes: str = ", ".join([f"{key}: {value}" for key, value in vars(self).items()])
+        attributes: str = ", ".join(f"{name}: {getattr(self, name)}" for name in self.__slots__)
         return f"{self.__class__.__name__}({attributes})"
 
     def __eq__(
@@ -986,10 +940,10 @@ def _recursive_mapping(  # noqa: PLR0911
         }
 
     elif isinstance(value, Mapping | typing.Mapping):
-        return {key: _recursive_mapping(element) for key, element in value.items()}
+        return {key: _recursive_mapping(element) for key, element in value.items()}  # pyright: ignore[reportUnknownVariableType]
 
     elif isinstance(value, Iterable | typing.Iterable):
-        return [_recursive_mapping(element) for element in value]
+        return [_recursive_mapping(element) for element in value]  # pyright: ignore[reportUnknownVariableType]
 
     elif hasattr(value, "to_mapping") and callable(value.to_mapping):
         return value.to_mapping()
