@@ -16,6 +16,7 @@ from logging import Logger
 from types import TracebackType
 from typing import Any, final, overload
 
+from haiway.attributes import State
 from haiway.context.disposables import Disposable, Disposables
 from haiway.context.events import EventsContext, EventSubscription
 from haiway.context.identifier import ScopeIdentifier
@@ -35,7 +36,7 @@ from haiway.context.presets import (
 from haiway.context.state import ScopeState, StateContext
 from haiway.context.tasks import TaskGroupContext
 from haiway.context.variables import VariablesContext
-from haiway.state import Immutable, State
+from haiway.types import Immutable
 from haiway.utils.collections import as_list
 from haiway.utils.stream import AsyncStream
 
@@ -415,10 +416,9 @@ class ctx:
 
     @staticmethod
     def scope(
-        name: str,
+        scope: ContextPreset | str,
         /,
         *state: State | None,
-        preset: ContextPreset | None = None,
         disposables: Disposables | Collection[Disposable] | None = None,
         observability: Observability | Logger | None = None,
         isolated: bool = False,
@@ -446,18 +446,16 @@ class ctx:
 
         Parameters
         ----------
-        name: str
-            name of the scope context, can be associated with state presets
+        scope: ContextPreset | str
+            Either a name of the scope context (can be associated with state presets with
+            matching name from preset registry), or a context preset to be used directly
+            within the scope context. When a preset is provided directly, its state and
+            disposables will be applied to the scope with lower priority than explicit state.
 
         *state: State | None
             state propagated within the scope context, will be merged with current state by
             replacing current with provided on conflict.
 
-        preset: ContextPreset | None = None
-            context preset to be used within the scope context. The preset's state and
-            disposables will be applied to the scope with lower priority than explicit state.
-            Only works with async contexts.
-
         disposables: Disposables | Collection[Disposable] | None
             disposables consumed within the context when entered. Produced state will automatically
             be added to the scope state. Using asynchronous context is required if any disposables
@@ -482,7 +480,7 @@ class ctx:
 
         Examples
         --------
-        Using a preset directly:
+        Using a preset directly (new approach):
 
         >>> from haiway import ctx, State
         >>> from haiway.context import ContextPreset
@@ -496,17 +494,17 @@ class ctx:
         ...     state=[ApiConfig(base_url="https://api.example.com")]
         ... )
         >>>
-        >>> # Direct preset usage
-        >>> async with ctx.scope("main", preset=api_preset):
+        >>> # Direct preset usage - pass preset instead of name
+        >>> async with ctx.scope(api_preset):
         ...     config = ctx.state(ApiConfig)
         ...     # Uses preset configuration
         >>>
         >>> # Override preset state with explicit state
-        >>> async with ctx.scope("main", ApiConfig(timeout=60), preset=api_preset):
+        >>> async with ctx.scope(api_preset, ApiConfig(timeout=60)):
         ...     config = ctx.state(ApiConfig)
         ...     # base_url from preset, timeout overridden to 60
 
-        Using preset registry (original approach):
+        Using preset registry with name lookup:
 
         >>> # Multiple presets registered
         >>> with ctx.presets(dev_preset, prod_preset):
@@ -519,16 +517,25 @@ class ctx:
         ContextPreset : For creating preset configurations
         """
 
+        name: str
+        preset: ContextPreset | None
+        if isinstance(scope, ContextPreset):
+            name = scope.name
+            preset = scope
+
+        else:
+            name = scope
+            preset = None
+
         resolved_disposables: Disposables | None
-        match disposables:
-            case None:
-                resolved_disposables = None
+        if disposables is None:
+            resolved_disposables = None
 
-            case Disposables() as disposables:
-                resolved_disposables = disposables
+        elif isinstance(disposables, Disposables):
+            resolved_disposables = disposables
 
-            case collection:
-                resolved_disposables = Disposables(collection)
+        else:
+            resolved_disposables = Disposables(disposables)
 
         return ScopeContext(
             name=name,
@@ -608,9 +615,25 @@ class ctx:
             )
         )
 
+    @overload
+    @staticmethod
+    def spawn[Result](
+        coro: Coroutine[Any, Any, Result],
+        /,
+    ) -> Task[Result]: ...
+
+    @overload
     @staticmethod
     def spawn[Result, **Arguments](
-        function: Callable[Arguments, Coroutine[Any, Any, Result]],
+        coro: Callable[Arguments, Coroutine[Any, Any, Result]],
+        /,
+        *args: Arguments.args,
+        **kwargs: Arguments.kwargs,
+    ) -> Task[Result]: ...
+
+    @staticmethod
+    def spawn[Result, **Arguments](
+        coro: Callable[Arguments, Coroutine[Any, Any, Result]] | Coroutine[Any, Any, Result],
         /,
         *args: Arguments.args,
         **kwargs: Arguments.kwargs,
@@ -618,12 +641,12 @@ class ctx:
         """
         Spawn an async task within current scope context task group.
 
-        When called outside of context, it will spawn detached task instead.
+        When called outside of context, it will spawn a background task instead.
 
         Parameters
         ----------
-        function: Callable[Arguments, Coroutine[Any, Any, Result]]
-            function to be called within the task group
+        coro: Callable[Arguments, Coroutine[Any, Any, Result]] | Coroutine[Any, Any, Result]
+            function or coroutine to be called within the task group
 
         *args: Arguments.args
             positional arguments passed to function call
@@ -637,11 +660,56 @@ class ctx:
             task for tracking function execution and result
         """
 
-        return TaskGroupContext.run(function, *args, **kwargs)
+        return TaskGroupContext.run(coro, *args, **kwargs)
+
+    @overload
+    @staticmethod
+    def spawn_background[Result](
+        coro: Coroutine[Any, Any, Result],
+        /,
+    ) -> Task[Result]: ...
+
+    @overload
+    @staticmethod
+    def spawn_background[Result, **Arguments](
+        coro: Callable[Arguments, Coroutine[Any, Any, Result]],
+        /,
+        *args: Arguments.args,
+        **kwargs: Arguments.kwargs,
+    ) -> Task[Result]: ...
+
+    @staticmethod
+    def spawn_background[Result, **Arguments](
+        coro: Callable[Arguments, Coroutine[Any, Any, Result]] | Coroutine[Any, Any, Result],
+        /,
+        *args: Arguments.args,
+        **kwargs: Arguments.kwargs,
+    ) -> Task[Result]:
+        """
+        Spawn an async task within background task group.
+
+        Parameters
+        ----------
+        coro: Callable[Arguments, Coroutine[Any, Any, Result]] | Coroutine[Any, Any, Result]
+            function or coroutine to be called within the task group
+
+        *args: Arguments.args
+            positional arguments passed to function call
+
+        **kwargs: Arguments.kwargs
+            keyword arguments passed to function call
+
+        Returns
+        -------
+        Task[Result]
+            task for tracking function execution and result
+        """
+
+        return TaskGroupContext.background_run(coro, *args, **kwargs)
 
     @staticmethod
     def stream[Element, **Arguments](
-        source: Callable[Arguments, AsyncGenerator[Element, None]],
+        source: Callable[Arguments, AsyncGenerator[Element]],
         /,
         *args: Arguments.args,
         **kwargs: Arguments.kwargs,
@@ -754,7 +822,7 @@ class ctx:
 
     @staticmethod
     def state[StateType: State](
-        state: type[StateType] | StateType,
+        state: type[StateType],
         /,
         default: StateType | None = None,
     ) -> StateType:
@@ -767,9 +835,8 @@ class ctx:
 
         Parameters
         ----------
-        state: type[StateType] | StateType
-            The State class type to retrieve from the current context, or an
-            instance to return directly
+        state: type[StateType]
+            The State class type to retrieve from the current context
         default: StateType | None, default=None
             Optional default instance to return if state is not found in context.
             If None and no state is found, a new instance will be created if possible.
@@ -815,9 +882,6 @@ class ctx:
         ...         config = ctx.state(DatabaseConfig)
         ...         # Use config to connect to database
         """
-        if not isinstance(state, type):
-            return state  # if we got an instance instead of type return it
-
         return StateContext.state(
             state,
             default=default,
